library(RPostgres)
library(magrittr)
library(tidyverse)
library(lubridate)

prepare_participants_file <- function() {

  username_list_csv_location <- snakemake@input[["username_list"]]

  data_configuration <- snakemake@params[["data_configuration"]]
  participants_container <- snakemake@params[["participants_table"]]
  device_id_container <- snakemake@params[["device_id_table"]]
  start_end_date_container <- snakemake@params[["start_end_date_table"]]

  usernames <- read_csv(username_list_csv_location, col_types = "c", progress = FALSE)

  participant_data <- pull_participants_ids(data_configuration, usernames, participants_container)
  participant_data %<>%
    rename(participant_id = id)

  device_ids <- pull_participants_device_ids(data_configuration, participant_data$participant_id, device_id_container)
  device_ids %<>%
    group_by(participant_id) %>%
    summarise(device_ids = list(unique(device_id)))
  participant_data %<>%
    left_join(device_ids, by = "participant_id")

  start_end_datetimes <- pull_participants_start_end_dates(data_configuration, participant_data$participant_id, start_end_date_container)
  participant_data %<>%
    left_join(start_end_datetimes, by = "participant_id")

  return(participant_data)
}


